@@ -416,8 +416,44 @@ pub fn node_neighbours_cubic(
 	source: (i32, i32, i32),
 	count_rings_from_origin: i32,
 ) -> Vec<(i32, i32, i32)> {
-	// the neighbours are on the first ring hence we hardcode the ring_number
-	node_ring_cubic(source, 1, count_rings_from_origin)
+	let mut neighbours = Vec::new();
+	// north (x, y + 1, z - 1)
+	if (source.1 + 1).abs() <= count_rings_from_origin
+		&& (source.2 - 1).abs() <= count_rings_from_origin
+	{
+		neighbours.push((source.0, source.1 + 1, source.2 - 1))
+	}
+	// north-east (x + 1, y, z - 1)
+	if (source.0 + 1).abs() <= count_rings_from_origin
+		&& (source.2 - 1).abs() <= count_rings_from_origin
+	{
+		neighbours.push((source.0 + 1, source.1, source.2 - 1))
+	}
+	// south-east (x + 1, y - 1, z)
+	if (source.0 + 1).abs() <= count_rings_from_origin
+		&& (source.1 - 1).abs() <= count_rings_from_origin
+	{
+		neighbours.push((source.0 + 1, source.1 - 1, source.2))
+	}
+	// south (x, y - 1, z + 1)
+	if (source.1 - 1).abs() <= count_rings_from_origin
+		&& (source.2 + 1).abs() <= count_rings_from_origin
+	{
+		neighbours.push((source.0, source.1 - 1, source.2 + 1))
+	}
+	// south-west (x - 1, y, z + 1)
+	if (source.0 - 1).abs() <= count_rings_from_origin
+		&& (source.2 + 1).abs() <= count_rings_from_origin
+	{
+		neighbours.push((source.0 - 1, source.1, source.2 + 1))
+	}
+	// north-west (x - 1, y + 1, z)
+	if (source.0 - 1).abs() <= count_rings_from_origin
+		&& (source.1 + 1).abs() <= count_rings_from_origin
+	{
+		neighbours.push((source.0 - 1, source.1 + 1, source.2))
+	}
+	neighbours
 }
 /// Finds the neighboring nodes in an Axial coordinate system. `source` is of the form
 /// `(q, r)` where `q` is the column and `r` the row. The node grid is in a circular arrangment
@@ -452,71 +488,137 @@ pub fn node_neighbours_axial(source: (i32, i32), count_rings_from_origin: i32) -
 	neighbours
 }
 /// Finds the nodes on a ring around a given source point in a Cubic coordinate system. `source` is of the form
-/// `(x, y, z)`. The node grid is in a circular arrangement with `count_rings_from_origin` being
-/// the number of rings around the origin of the entire grid, this prevents returning nodes which exist outside of the
-/// grid - the value is inclusive. 'ring_number' is the particular ring you want to know the nodes of
+/// `(x, y, z)`. `radius` is the particular ring you want to know the nodes of.
 ///
-/// For instance:
+/// For instance `radius = 2` for the second ring around the origin:
 /// ```txt
-///              _______
-///             /   0   \
-///     _______/         \_______
-///    /  -1   \ 1    -1 /   1   \
-///   /         \_______/         \
-///   \ 1     0 /   x   \ 0    -1 /
-///    \_______/         \_______/
-///    /  -1   \ y     z /   1   \
-///   /         \_______/         \
-///   \ 0     1 /   0   \ -1    0 /
-///    \_______/         \_______/
-///            \ -1    1 /
-///             \_______/
+///                     _______
+///                    /       \
+///            _______/  RING2  \_______
+///           /       \         /       \
+///   _______/  RING2  \_______/  RING2  \_______
+///  /       \         /       \         /       \
+/// /  RING2  \_______/         \_______/  RING2  \
+/// \         /       \         /       \         /
+///  \_______/         \_______/         \_______/
+///  /       \         /   x   \         /       \
+/// /  RING2  \_______/         \_______/  RING2  \
+/// \         /       \ y     z /       \         /
+///  \_______/         \_______/         \_______/
+///  /       \         /       \         /       \
+/// /  RING2  \_______/         \_______/  RING2  \
+/// \         /       \         /       \         /
+///  \_______/  RING2  \_______/  RING2  \_______/
+///          \         /       \         /
+///           \_______/  RING2  \_______/
+///                   \         /
+///                    \_______/
 /// ```
-/// With a `ring_number = 1` will find the immediate neighbouring nodes around the centre
-#[allow(clippy::int_plus_one)]
-pub fn node_ring_cubic(
-	source: (i32, i32, i32),
-	ring_number: i32,
-	count_rings_from_origin: i32,
-) -> Vec<(i32, i32, i32)> {
-	let mut neighbours = Vec::new();
-	// north (x, y + ring_number, z - ring_number)
-	if (source.1 + ring_number).abs() <= count_rings_from_origin
-		&& (source.2 - ring_number).abs() <= count_rings_from_origin
-	{
-		neighbours.push((source.0, source.1 + ring_number, source.2 - ring_number))
+pub fn node_ring_cubic(source: (i32, i32, i32), radius: i32) -> Vec<(i32, i32, i32)> {
+	let mut ring_nodes = Vec::new();
+	// unit lengths to move in a direction of a face, the array starts with the North direction
+	// moving clockwise for each edge
+	//         N
+	//      _______
+	//     /       \
+	// NW /         \ NE
+	// SW \         / SE
+	//     \_______/
+	//         S
+	let cube_directions = [
+		(0, 1, -1),
+		(1, 0, -1),
+		(1, -1, 0),
+		(0, -1, 1),
+		(-1, 0, 1),
+		(-1, 1, 0),
+	];
+	// from the starting node move to the node joining the south-west and west faces, e.g for radius =2:
+	//                            _________
+	//                           /         \
+	//                          /           \
+	//                _________/             \_________
+	//               /         \             /         \
+	//              /           \           /           \
+	//    _________/             \_________/             \_________
+	//   /         \             /         \             /         \
+	//  /           \           /           \           /           \
+	// /             \_________/             \_________/             \
+	// \             /         \             /         \             /
+	//  \           /           \           /           \           /
+	//   \_________/             \_________/             \_________/
+	//   /         \             /    x    \             /         \
+	//  /           \           /           \           /           \
+	// /             \_________/   SOURCE    \_________/             \
+	// \             /         \ y         z /         \             /
+	//  \           /           \           /           \           /
+	//   \_________/             \_________/             \_________/
+	//   /         \             /         \             /         \
+	//  /           \           /           \           /           \
+	// /    START    \_________/             \_________/             \
+	// \             /         \             /         \             /
+	//  \           /           \           /           \           /
+	//   \_________/             \_________/             \_________/
+	//             \             /         \             /
+	//              \           /           \           /
+	//               \_________/             \_________/
+	//                         \             /
+	//                          \           /
+	//                           \_________/
+	let scaled_x = cube_directions[4].0 * radius;
+	let scaled_y = cube_directions[4].1 * radius;
+	let scaled_z = cube_directions[4].2 * radius;
+	let mut ring_node_current = (
+		source.0 + scaled_x,
+		source.1 + scaled_y,
+		source.2 + scaled_z,
+	);
+	// from the node starting on the ring we can walk around the ring discovering all the nodes on it
+	// iterate to 6 as a hexagon has 6 faces, we walk along each side of the hex ring
+	for i in 0..6 {
+		// the length of each face is denoted by the radius
+		// e.g radius + 1, so for radius = 2 the sides have length 3 but we only take two steps at a time as to not overlap:
+		//                            _________
+		//                           /         \
+		//                          /           \
+		//                _________/             \_________
+		//               /         \             /         \
+		//              /           \     i=1   /           \
+		//    _________/             \_________/             \_________
+		//   /         \             /         \             /         \
+		//  /           \     i=1   /           \     i=2   /           \
+		// /             \_________/             \_________/             \
+		// \             /         \             /         \             /
+		//  \    i=0    /           \           /           \     i=2   /
+		//   \_________/             \_________/             \_________/
+		//   /         \             /    x    \             /         \
+		//  /           \           /           \           /           \
+		// /             \_________/             \_________/             \
+		// \             /         \ y         z /         \             /
+		//  \    i=0    /           \           /           \     i=3   /
+		//   \_________/             \_________/             \_________/
+		//   /         \             /         \             /         \
+		//  /           \           /           \           /           \
+		// /    START    \_________/             \_________/             \
+		// \             /         \             /         \             /
+		//  \    i=5    /           \           /           \     i=3   /
+		//   \_________/             \_________/             \_________/
+		//             \             /         \             /
+		//              \     i=5   /           \     i=4   /
+		//               \_________/             \_________/
+		//                         \             /
+		//                          \     i=4   /
+		//                           \_________/
+		for _j in 0..radius {
+			// move to next node
+			ring_node_current.0 += cube_directions[i].0;
+			ring_node_current.1 += cube_directions[i].1;
+			ring_node_current.2 += cube_directions[i].2;
+			// store node
+			ring_nodes.push(ring_node_current);
+		}
 	}
-	// north-east (x + ring_number, y, z - ring_number)
-	if (source.0 + ring_number).abs() <= count_rings_from_origin
-		&& (source.2 - ring_number).abs() <= count_rings_from_origin
-	{
-		neighbours.push((source.0 + ring_number, source.1, source.2 - ring_number))
-	}
-	// south-east (x + ring_number, y - ring_number, z)
-	if (source.0 + ring_number).abs() <= count_rings_from_origin
-		&& (source.1 - ring_number).abs() <= count_rings_from_origin
-	{
-		neighbours.push((source.0 + ring_number, source.1 - ring_number, source.2))
-	}
-	// south (x, y - ring_number, z + ring_number)
-	if (source.1 - ring_number).abs() <= count_rings_from_origin
-		&& (source.2 + ring_number).abs() <= count_rings_from_origin
-	{
-		neighbours.push((source.0, source.1 - ring_number, source.2 + ring_number))
-	}
-	// south-west (x - ring_number, y, z + ring_number)
-	if (source.0 - ring_number).abs() <= count_rings_from_origin
-		&& (source.2 + ring_number).abs() <= count_rings_from_origin
-	{
-		neighbours.push((source.0 - ring_number, source.1, source.2 + ring_number))
-	}
-	// north-west (x - ring_number, y + ring_number, z)
-	if (source.0 - ring_number).abs() <= count_rings_from_origin
-		&& (source.1 + ring_number).abs() <= count_rings_from_origin
-	{
-		neighbours.push((source.0 - ring_number, source.1 + ring_number, source.2))
-	}
-	neighbours
+	ring_nodes
 }
 
 /// The distance between two nodes by using cubic coordinates
@@ -817,4 +919,26 @@ mod tests {
 		let actual: (i32, i32) = (-1, -1);
 		assert_eq!(actual, result);
 	}
+	#[test]
+	/// test for node on a ring
+	fn ring() {
+		let source = (0, 0, 0);
+		let radius = 2;
+		let result = node_ring_cubic(source, radius);
+		let actual = vec![
+			(-2, 1, 1),
+			(-2, 2, 0),
+			(-1, 2, -1),
+			(0, 2, -2),
+			(1, 1, -2),
+			(2, 0, -2),
+			(2, -1, -1),
+			(2, -2, 0),
+			(1, -2, 1),
+			(0, -2, 2),
+			(-1, -1, 2),
+			(-2, 0, 2),
+		];
+		assert_eq!(actual, result);
+	}
 }
